@@ -1,4 +1,5 @@
 from pyspark.sql.functions import udf, lit
+import labelbox
 from labelbox.schema.data_row_metadata import DataRowMetadataKind
 from pyspark.sql.types import StructType, StructField, StringType, MapType, ArrayType
 import json
@@ -15,7 +16,7 @@ def refresh_metadata_ontology(client):
     lb_metadata_names = [field['name'] for field in lb_mdo._get_ontology()]
     return lb_mdo, lb_metadata_names
 
-def get_unique_values(spark_table, column_name)):
+def get_unique_values(spark_table, column_name):
     """ Grabs all unique values from a spark table column as strings
     Args:
         spark_table         :   Required (pyspark.sql.dataframe.Dataframe) - Databricks Spark Table object
@@ -74,7 +75,7 @@ def __create_upload_data_row_values(row_data_col, global_key_col, external_id_co
     metadata_name_key_to_schema = json.loads(metadata_name_key_to_schema_bytes)
     return {"row_data" : row_data_col, "external_id" : external_id_col, "global_key" : global_key_col, "metadata_fields" : [{"schema_id" : metadata_name_key_to_schema["lb_integration_source"], "value" : "Databricks"}]}
 
-def get_metadata_schema_to_name_key(lb_mdo:labelbox.schema.data_row_metadata.DataRowMetadataOntology. divider="///", invert=False):
+def get_metadata_schema_to_name_key(lb_mdo:labelbox.schema.data_row_metadata.DataRowMetadataOntology, divider="///", invert=False):
     """ Creates a dictionary where {key=metadata_schema_id: value=metadata_name_key} 
     - name_key is name for all metadata fields, and for enum options, it is "parent_name{divider}child_name"
     Args:
@@ -248,4 +249,4 @@ def metadata_upsert_udf():
     Returns:
         UDF object to-be-run using: spark_dataframe.withColumn(col_name, udf(**kwargs))
     """      
-    return udf(upsert_function(), StringType())
\ No newline at end of file
+    return udf(upsert_function(), StringType())
